# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.tags_api import TagsApi


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.tags_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_tag(self, m) -> None:
        """Test case for add_tag

        Add a tag
        """
        path = urljoin("https://api.accounting.sh", "/tags")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.tags_api.add_tag(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_tag(self, m) -> None:
        """Test case for delete_tag

        Delete a tag
        """
        path = urljoin("https://api.accounting.sh", "/tags/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.tags_api.delete_tag(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_tag(self, m) -> None:
        """Test case for get_tag

        Get a tag
        """
        path = urljoin("https://api.accounting.sh", "/tags/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.tags_api.get_tag(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_tags(self, m) -> None:
        """Test case for list_tags

        List company's tags
        """
        path = urljoin("https://api.accounting.sh", "/tags")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.tags_api.list_tags(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_tags_by_resource(self, m) -> None:
        """Test case for list_tags_by_resource

        List company's tags by resource attachment
        """
        path = urljoin("https://api.accounting.sh", "/tags/attachments/{resource}")
        path = path.replace("{" + "resource" + "}", "resource_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.tags_api.list_tags_by_resource(
                "resource_example",
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_tag(self, m) -> None:
        """Test case for update_tag

        Update a tag
        """
        path = urljoin("https://api.accounting.sh", "/tags/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.tags_api.update_tag(
                "uuid_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.account_connections_api import AccountConnectionsApi


class TestAccountConnectionsApi(unittest.TestCase):
    """AccountConnectionsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.account_connections_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_delete_account_connection(self, m) -> None:
        """Test case for delete_account_connection

        Delete an account's connection
        """
        path = urljoin(
            "https://api.accounting.sh", "/accounts/{uuid}/connect/{connection}"
        )
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        path = path.replace("{" + "connection" + "}", "connection_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.account_connections_api.delete_account_connection(
                "uuid_example",
                "connection_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_account_connections(self, m) -> None:
        """Test case for list_account_connections

        List account's connections
        """
        path = urljoin("https://api.accounting.sh", "/accounts/{uuid}/connect")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.account_connections_api.list_account_connections(
                "uuid_example",
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_banks(self, m) -> None:
        """Test case for list_banks

        List available bank connections
        """
        path = urljoin("https://api.accounting.sh", "/accounts/{uuid}/connect/banks")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.account_connections_api.list_banks(
                "uuid_example",
                "country_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_connectable_bank_accounts(self, m) -> None:
        """Test case for list_connectable_bank_accounts

        List connectable bank accounts
        """
        path = urljoin("https://api.accounting.sh", "/accounts/{uuid}/connect/accounts")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.account_connections_api.list_connectable_bank_accounts(
                "uuid_example",
                "connection_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_connected_account_transactions(self, m) -> None:
        """Test case for list_connected_account_transactions

        List the connected account's transactions
        """
        path = urljoin(
            "https://api.accounting.sh", "/accounts/{uuid}/connect/{connection}"
        )
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        path = path.replace("{" + "connection" + "}", "connection_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.account_connections_api.list_connected_account_transactions(
                "uuid_example",
                "connection_example",
                3.4,
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_request_bank_connection(self, m) -> None:
        """Test case for request_bank_connection

        Request a new bank connection
        """
        path = urljoin("https://api.accounting.sh", "/accounts/{uuid}/connect/request")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.account_connections_api.request_bank_connection(
                "uuid_example",
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_select_bank_account(self, m) -> None:
        """Test case for select_bank_account

        Select a bank account to connect
        """
        path = urljoin("https://api.accounting.sh", "/accounts/{uuid}/connect/accounts")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.account_connections_api.select_bank_account(
                "uuid_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.statistics_api import StatisticsApi


class TestStatisticsApi(unittest.TestCase):
    """StatisticsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.statistics_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_summary_statistics_period(self, m) -> None:
        """Test case for summary_statistics_period

        Company's summary statistics
        """
        path = urljoin(
            "https://api.accounting.sh", "/companies/{uuid}/statistics/summary"
        )
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.statistics_api.summary_statistics_period(
                "uuid_example",
                "2013-10-20",
                "2013-10-20",
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import warnings
from datetime import date, datetime
from json import dumps
from typing import Any, Dict, List, Optional, Tuple, Union
from urllib.parse import urlencode

from typing_extensions import Annotated


class QuotesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, accounting) -> None:
        self.accounting = accounting

    def add_quote(self, add_quote_request: dict, **kwargs) -> Any | None:
        """Add a quote


        :param add_quote_request: (required)
        :type add_quote_request: AddQuoteRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/quotes"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if add_quote_request is not None:
            kwargs["json"] = add_quote_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)

    def delete_quote(self, uuid: str, **kwargs) -> Any | None:
        """Delete a quote


        :param uuid: The quote uuid (required)
        :type uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/quotes/{uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="DELETE", path=path, **kwargs)

    def get_quote(self, uuid: str, **kwargs) -> Any | None:
        """Get a quote


        :param uuid: The quote uuid (required)
        :type uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/quotes/{uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def get_quote_document(self, uuid: str, **kwargs) -> Any | None:
        """Get a quote in PDF


        :param uuid: The quote uuid (required)
        :type uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/quotes/{uuid}/document"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def list_quotes(
        self, fields: str = None, page: str = None, per_page: str = None, **kwargs
    ) -> Any | None:
        """List company's quotes


        :param fields: A comma separated list of fields requested in the response
        :type fields: str
        :param page: The response page
        :type page: str
        :param per_page: The number of items per page
        :type per_page: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/quotes"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if fields is not None:

            query_params["fields"] = fields

        if page is not None:

            query_params["page"] = page

        if per_page is not None:

            query_params["per_page"] = per_page

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def update_quote(self, uuid: str, add_quote_request: dict, **kwargs) -> Any | None:
        """Update a quote


        :param uuid: The quote uuid (required)
        :type uuid: str
        :param add_quote_request: (required)
        :type add_quote_request: AddQuoteRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/quotes/{uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if add_quote_request is not None:
            kwargs["json"] = add_quote_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="PUT", path=path, **kwargs)



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import warnings
from datetime import date, datetime
from json import dumps
from typing import Any, Dict, List, Optional, Tuple, Union
from urllib.parse import urlencode

from typing_extensions import Annotated


class AccountConnectionsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, accounting) -> None:
        self.accounting = accounting

    def delete_account_connection(
        self, uuid: str, connection: str, **kwargs
    ) -> Any | None:
        """Delete an account's connection


        :param uuid: The account uuid (required)
        :type uuid: str
        :param connection: The connection uuid (required)
        :type connection: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/accounts/{uuid}/connect/{connection}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if connection is not None:
            path = path.replace("{" + "connection" + "}", connection)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="DELETE", path=path, **kwargs)

    def list_account_connections(
        self,
        uuid: str,
        fields: str = None,
        page: str = None,
        per_page: str = None,
        **kwargs,
    ) -> Any | None:
        """List account's connections


        :param uuid: The account uuid (required)
        :type uuid: str
        :param fields: A comma separated list of fields requested in the response
        :type fields: str
        :param page: The response page
        :type page: str
        :param per_page: The number of items per page
        :type per_page: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/accounts/{uuid}/connect"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if fields is not None:

            query_params["fields"] = fields

        if page is not None:

            query_params["page"] = page

        if per_page is not None:

            query_params["per_page"] = per_page

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def list_banks(self, uuid: str, country: str = None, **kwargs) -> Any | None:
        """List available bank connections


        :param uuid: The account uuid (required)
        :type uuid: str
        :param country: A two letter country code, if none are specified, the company's country is used
        :type country: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/accounts/{uuid}/connect/banks"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if country is not None:

            query_params["country"] = country

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def list_connectable_bank_accounts(
        self, uuid: str, connection: str = None, **kwargs
    ) -> Any | None:
        """List connectable bank accounts


        :param uuid: The account uuid (required)
        :type uuid: str
        :param connection: The connection request UUID
        :type connection: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/accounts/{uuid}/connect/accounts"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if connection is not None:

            query_params["connection"] = connection

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def list_connected_account_transactions(
        self, uuid: str, connection: str, period: float = None, **kwargs
    ) -> Any | None:
        """List the connected account's transactions


        :param uuid: The account uuid (required)
        :type uuid: str
        :param connection: The connection uuid (required)
        :type connection: str
        :param period: The number of days to look back for transactions. Default is 7 days.
        :type period: float
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/accounts/{uuid}/connect/{connection}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if connection is not None:
            path = path.replace("{" + "connection" + "}", connection)
        if period is not None:

            query_params["period"] = period

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def request_bank_connection(
        self, uuid: str, request_bank_connection_request: dict, **kwargs
    ) -> Any | None:
        """Request a new bank connection


        :param uuid: The account uuid (required)
        :type uuid: str
        :param request_bank_connection_request: (required)
        :type request_bank_connection_request: RequestBankConnectionRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/accounts/{uuid}/connect/request"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if request_bank_connection_request is not None:
            kwargs["json"] = request_bank_connection_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)

    def select_bank_account(
        self, uuid: str, select_bank_account_request: dict, **kwargs
    ) -> Any | None:
        """Select a bank account to connect


        :param uuid: The account uuid (required)
        :type uuid: str
        :param select_bank_account_request: (required)
        :type select_bank_account_request: SelectBankAccountRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/accounts/{uuid}/connect/accounts"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if select_bank_account_request is not None:
            kwargs["json"] = select_bank_account_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import warnings
from datetime import date, datetime
from json import dumps
from typing import Any, Dict, List, Optional, Tuple, Union
from urllib.parse import urlencode

from typing_extensions import Annotated


class TransactionsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, accounting) -> None:
        self.accounting = accounting

    def add_link(
        self, list_links200_response_links_inner: dict, uuid: str = None, **kwargs
    ) -> Any | None:
        """Add a new transaction link


        :param list_links200_response_links_inner: (required)
        :type list_links200_response_links_inner: ListLinks200ResponseLinksInner
        :param uuid: A transaction uuid
        :type uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/{uuid}/links"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if list_links200_response_links_inner is not None:
            kwargs["json"] = list_links200_response_links_inner

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)

    def add_transaction(self, add_transaction_request: dict, **kwargs) -> Any | None:
        """Add a transaction


        :param add_transaction_request: (required)
        :type add_transaction_request: AddTransactionRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if add_transaction_request is not None:
            kwargs["json"] = add_transaction_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)

    def add_transaction_code(
        self, uuid: str, update_transaction_code_request: dict, **kwargs
    ) -> Any | None:
        """Add a transaction's code


        :param uuid: The transaction uuid (required)
        :type uuid: str
        :param update_transaction_code_request: (required)
        :type update_transaction_code_request: UpdateTransactionCodeRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/{uuid}/codes"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if update_transaction_code_request is not None:
            kwargs["json"] = update_transaction_code_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)

    def delete_link(
        self, uuid: str = None, link_uuid: str = None, **kwargs
    ) -> Any | None:
        """Delete a transaction link


        :param uuid: A transaction uuid
        :type uuid: str
        :param link_uuid: A transaction link uuid OR the target uuid
        :type link_uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/{uuid}/links/{link_uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if link_uuid is not None:
            path = path.replace("{" + "link_uuid" + "}", link_uuid)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="DELETE", path=path, **kwargs)

    def delete_transaction(self, uuid: str, **kwargs) -> Any | None:
        """Delete a transaction


        :param uuid: The transaction uuid (required)
        :type uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/{uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="DELETE", path=path, **kwargs)

    def delete_transaction_code(self, uuid: str, code: str, **kwargs) -> Any | None:
        """Delete a transaction's code


        :param uuid: The transaction uuid (required)
        :type uuid: str
        :param code: The transaction's code uuid (required)
        :type code: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/{uuid}/codes/{code}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if code is not None:
            path = path.replace("{" + "code" + "}", code)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="DELETE", path=path, **kwargs)

    def get_transaction(self, uuid: str, **kwargs) -> Any | None:
        """Get a transaction


        :param uuid: The transaction uuid (required)
        :type uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/{uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def import_transactions(
        self, import_transactions_request: dict, **kwargs
    ) -> Any | None:
        """Import transactions - INTERNAL

        Import transaction from a file or directly from extracted details

        :param import_transactions_request: (required)
        :type import_transactions_request: ImportTransactionsRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/import"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if import_transactions_request is not None:
            kwargs["json"] = import_transactions_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)

    def ledger(
        self,
        fields: str = None,
        page: str = None,
        per_page: str = None,
        account: str = None,
        **kwargs,
    ) -> Any | None:
        """List company's transactions and transfers


        :param fields: A comma separated list of fields requested in the response
        :type fields: str
        :param page: The response page
        :type page: str
        :param per_page: The number of items per page
        :type per_page: str
        :param account: An account uuid to filter results
        :type account: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/ledger"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if fields is not None:

            query_params["fields"] = fields

        if page is not None:

            query_params["page"] = page

        if per_page is not None:

            query_params["per_page"] = per_page

        if account is not None:

            query_params["account"] = account

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def list_links(
        self,
        fields: str = None,
        page: str = None,
        per_page: str = None,
        uuid: str = None,
        **kwargs,
    ) -> Any | None:
        """List a transaction links


        :param fields: A comma separated list of fields requested in the response
        :type fields: str
        :param page: The response page
        :type page: str
        :param per_page: The number of items per page
        :type per_page: str
        :param uuid: A transaction uuid
        :type uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/{uuid}/links"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if fields is not None:

            query_params["fields"] = fields

        if page is not None:

            query_params["page"] = page

        if per_page is not None:

            query_params["per_page"] = per_page

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def list_transaction_codes(
        self,
        uuid: str,
        fields: str = None,
        page: str = None,
        per_page: str = None,
        account: str = None,
        **kwargs,
    ) -> Any | None:
        """List transaction's codes


        :param uuid: The transaction uuid (required)
        :type uuid: str
        :param fields: A comma separated list of fields requested in the response
        :type fields: str
        :param page: The response page
        :type page: str
        :param per_page: The number of items per page
        :type per_page: str
        :param account: List to the specified account
        :type account: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/{uuid}/codes"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if fields is not None:

            query_params["fields"] = fields

        if page is not None:

            query_params["page"] = page

        if per_page is not None:

            query_params["per_page"] = per_page

        if account is not None:

            query_params["account"] = account

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def list_transactions(
        self,
        fields: str = None,
        page: str = None,
        per_page: str = None,
        account: str = None,
        **kwargs,
    ) -> Any | None:
        """List company's transactions


        :param fields: A comma separated list of fields requested in the response
        :type fields: str
        :param page: The response page
        :type page: str
        :param per_page: The number of items per page
        :type per_page: str
        :param account: List to the specified account
        :type account: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if fields is not None:

            query_params["fields"] = fields

        if page is not None:

            query_params["page"] = page

        if per_page is not None:

            query_params["per_page"] = per_page

        if account is not None:

            query_params["account"] = account

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def update_link(
        self,
        list_links200_response_links_inner: dict,
        uuid: str = None,
        link_uuid: str = None,
        **kwargs,
    ) -> Any | None:
        """Update a transaction link


        :param list_links200_response_links_inner: (required)
        :type list_links200_response_links_inner: ListLinks200ResponseLinksInner
        :param uuid: A transaction uuid
        :type uuid: str
        :param link_uuid: A transaction link uuid OR the target uuid
        :type link_uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/{uuid}/links/{link_uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if link_uuid is not None:
            path = path.replace("{" + "link_uuid" + "}", link_uuid)
        if list_links200_response_links_inner is not None:
            kwargs["json"] = list_links200_response_links_inner

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="PUT", path=path, **kwargs)

    def update_transaction(
        self, uuid: str, add_transaction_request: dict, **kwargs
    ) -> Any | None:
        """Update a transaction


        :param uuid: The transaction uuid (required)
        :type uuid: str
        :param add_transaction_request: (required)
        :type add_transaction_request: AddTransactionRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/{uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if add_transaction_request is not None:
            kwargs["json"] = add_transaction_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="PUT", path=path, **kwargs)

    def update_transaction_code(
        self, uuid: str, update_transaction_code_request: dict, **kwargs
    ) -> Any | None:
        """Update a transaction's code


        :param uuid: The transaction uuid (required)
        :type uuid: str
        :param update_transaction_code_request: (required)
        :type update_transaction_code_request: UpdateTransactionCodeRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/{uuid}/codes"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if update_transaction_code_request is not None:
            kwargs["json"] = update_transaction_code_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="PUT", path=path, **kwargs)

    def view_link(
        self, uuid: str = None, link_uuid: str = None, **kwargs
    ) -> Any | None:
        """View a transaction link


        :param uuid: A transaction uuid
        :type uuid: str
        :param link_uuid: A transaction link uuid OR the target uuid
        :type link_uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/transactions/{uuid}/links/{link_uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if link_uuid is not None:
            path = path.replace("{" + "link_uuid" + "}", link_uuid)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.accounting_codes_api import AccountingCodesApi


class TestAccountingCodesApi(unittest.TestCase):
    """AccountingCodesApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.accounting_codes_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_accounting_code(self, m) -> None:
        """Test case for add_accounting_code

        Add an accounting code
        """
        path = urljoin("https://api.accounting.sh", "/accounting/codes")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.accounting_codes_api.add_accounting_code(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_accounting_code(self, m) -> None:
        """Test case for delete_accounting_code

        Delete an accounting code
        """
        path = urljoin("https://api.accounting.sh", "/accounting/codes/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.accounting_codes_api.delete_accounting_code(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_accounting_code(self, m) -> None:
        """Test case for get_accounting_code

        Get an accounting code
        """
        path = urljoin("https://api.accounting.sh", "/accounting/codes/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.accounting_codes_api.get_accounting_code(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_accounting_codes(self, m) -> None:
        """Test case for list_accounting_codes

        List company's accounting code
        """
        path = urljoin("https://api.accounting.sh", "/accounting/codes")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert accounting.accounting_codes_api.list_accounting_codes() is not None

    @requests_mock.Mocker()
    def test_update_accounting_code(self, m) -> None:
        """Test case for update_accounting_code

        Update an accounting code
        """
        path = urljoin("https://api.accounting.sh", "/accounting/codes/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.accounting_codes_api.update_accounting_code(
                "uuid_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.accounts_api import AccountsApi


class TestAccountsApi(unittest.TestCase):
    """AccountsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.accounts_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_account(self, m) -> None:
        """Test case for add_account

        Add an account
        """
        path = urljoin("https://api.accounting.sh", "/accounts")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.accounts_api.add_account(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_account(self, m) -> None:
        """Test case for delete_account

        Delete an account
        """
        path = urljoin("https://api.accounting.sh", "/accounts/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.accounts_api.delete_account(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_account(self, m) -> None:
        """Test case for get_account

        Get an account
        """
        path = urljoin("https://api.accounting.sh", "/accounts/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.accounts_api.get_account(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_accounts(self, m) -> None:
        """Test case for list_accounts

        List company's accounts
        """
        path = urljoin("https://api.accounting.sh", "/accounts")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.accounts_api.list_accounts(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_account(self, m) -> None:
        """Test case for update_account

        Update an account
        """
        path = urljoin("https://api.accounting.sh", "/accounts/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.accounts_api.update_account(
                "uuid_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.countries_api import CountriesApi


class TestCountriesApi(unittest.TestCase):
    """CountriesApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.countries_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_get_translated_countries(self, m) -> None:
        """Test case for get_translated_countries

        Get translated list of countries
        """
        path = urljoin("https://api.accounting.sh", "/countries/{lang}")
        path = path.replace("{" + "lang" + "}", "lang_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.countries_api.get_translated_countries(
                "lang_example",
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# flake8: noqa

# import apis into api package
from accounting_sh.api.account_connections_api import AccountConnectionsApi
from accounting_sh.api.accounting_codes_api import AccountingCodesApi
from accounting_sh.api.accounts_api import AccountsApi
from accounting_sh.api.attachments_api import AttachmentsApi
from accounting_sh.api.auth_api import AuthApi
from accounting_sh.api.bills_api import BillsApi
from accounting_sh.api.categories_api import CategoriesApi
from accounting_sh.api.companies_api import CompaniesApi
from accounting_sh.api.contacts_api import ContactsApi
from accounting_sh.api.countries_api import CountriesApi
from accounting_sh.api.credentials_api import CredentialsApi
from accounting_sh.api.currency_api import CurrencyApi
from accounting_sh.api.documents_api import DocumentsApi
from accounting_sh.api.expense_reports_api import ExpenseReportsApi
from accounting_sh.api.export_api import ExportApi
from accounting_sh.api.invoices_api import InvoicesApi
from accounting_sh.api.logs_api import LogsApi
from accounting_sh.api.notification_api import NotificationApi
from accounting_sh.api.notification_types_api import NotificationTypesApi
from accounting_sh.api.o_auth_config_api import OAuthConfigApi
from accounting_sh.api.payments_api import PaymentsApi
from accounting_sh.api.quotes_api import QuotesApi
from accounting_sh.api.receipts_api import ReceiptsApi
from accounting_sh.api.revenues_api import RevenuesApi
from accounting_sh.api.rossum_api import RossumApi
from accounting_sh.api.search_api import SearchApi
from accounting_sh.api.settings_api import SettingsApi
from accounting_sh.api.statistics_api import StatisticsApi
from accounting_sh.api.tags_api import TagsApi
from accounting_sh.api.tax_api import TaxApi
from accounting_sh.api.transactions_api import TransactionsApi
from accounting_sh.api.transfers_api import TransfersApi
from accounting_sh.api.users_api import UsersApi
from accounting_sh.api.vatid_api import VATIDApi
from accounting_sh.api.webhooks_api import WebhooksApi



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.auth_api import AuthApi


class TestAuthApi(unittest.TestCase):
    """AuthApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.auth_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_auth_init(self, m) -> None:
        """Test case for auth_init

        Init authentication process
        """
        path = urljoin("https://api.accounting.sh", "/auth/init")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert accounting.auth_api.auth_init() is not None

    @requests_mock.Mocker()
    def test_login(self, m) -> None:
        """Test case for login

        Login user
        """
        path = urljoin("https://api.accounting.sh", "/auth/login")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.auth_api.login(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_logout(self, m) -> None:
        """Test case for logout

        Logout current user
        """
        path = urljoin("https://api.accounting.sh", "/auth/logout")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert accounting.auth_api.logout() is not None

    @requests_mock.Mocker()
    def test_switch_company(self, m) -> None:
        """Test case for switch_company

        Switch to a different company
        """
        path = urljoin("https://api.accounting.sh", "/auth/switch")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.auth_api.switch_company(
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.users_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_user(self, m) -> None:
        """Test case for add_user

        Add user
        """
        path = urljoin("https://api.accounting.sh", "/users")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.users_api.add_user(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_user(self, m) -> None:
        """Test case for delete_user

        Delete user
        """
        path = urljoin("https://api.accounting.sh", "/users/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.users_api.delete_user(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_user(self, m) -> None:
        """Test case for get_user

        View user
        """
        path = urljoin("https://api.accounting.sh", "/users/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.users_api.get_user(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_users(self, m) -> None:
        """Test case for list_users

        List company's users
        """
        path = urljoin("https://api.accounting.sh", "/users")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.users_api.list_users(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_user(self, m) -> None:
        """Test case for update_user

        Update user
        """
        path = urljoin("https://api.accounting.sh", "/users/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.users_api.update_user(
                "uuid_example",
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_users_companies(self, m) -> None:
        """Test case for users_companies

        List current user companies
        """
        path = urljoin("https://api.accounting.sh", "/users/me/companies")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert accounting.users_api.users_companies() is not None

    @requests_mock.Mocker()
    def test_users_me(self, m) -> None:
        """Test case for users_me

        View current user details
        """
        path = urljoin("https://api.accounting.sh", "/users/me")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert accounting.users_api.users_me() is not None


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import warnings
from datetime import date, datetime
from json import dumps
from typing import Any, Dict, List, Optional, Tuple, Union
from urllib.parse import urlencode

from typing_extensions import Annotated


class AuthApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, accounting) -> None:
        self.accounting = accounting

    def auth_init(self, **kwargs) -> Any | None:
        """Init authentication process


        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/auth/init"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def login(self, login_request: dict, **kwargs) -> Any | None:
        """Login user


        :param login_request: (required)
        :type login_request: LoginRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/auth/login"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if login_request is not None:
            kwargs["json"] = login_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)

    def logout(self, **kwargs) -> Any | None:
        """Logout current user


        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/auth/logout"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def switch_company(self, switch_company_request: dict, **kwargs) -> Any | None:
        """Switch to a different company


        :param switch_company_request: (required)
        :type switch_company_request: SwitchCompanyRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/auth/switch"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if switch_company_request is not None:
            kwargs["json"] = switch_company_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.transactions_api import TransactionsApi


class TestTransactionsApi(unittest.TestCase):
    """TransactionsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.transactions_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_link(self, m) -> None:
        """Test case for add_link

        Add a new transaction link
        """
        path = urljoin("https://api.accounting.sh", "/transactions/{uuid}/links")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.add_link(
                {},
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_add_transaction(self, m) -> None:
        """Test case for add_transaction

        Add a transaction
        """
        path = urljoin("https://api.accounting.sh", "/transactions")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.add_transaction(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_add_transaction_code(self, m) -> None:
        """Test case for add_transaction_code

        Add a transaction's code
        """
        path = urljoin("https://api.accounting.sh", "/transactions/{uuid}/codes")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.add_transaction_code(
                "uuid_example",
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_link(self, m) -> None:
        """Test case for delete_link

        Delete a transaction link
        """
        path = urljoin(
            "https://api.accounting.sh", "/transactions/{uuid}/links/{link_uuid}"
        )
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        path = path.replace("{" + "link_uuid" + "}", "link_uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.delete_link(
                "uuid_example",
                "link_uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_transaction(self, m) -> None:
        """Test case for delete_transaction

        Delete a transaction
        """
        path = urljoin("https://api.accounting.sh", "/transactions/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.delete_transaction(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_transaction_code(self, m) -> None:
        """Test case for delete_transaction_code

        Delete a transaction's code
        """
        path = urljoin("https://api.accounting.sh", "/transactions/{uuid}/codes/{code}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        path = path.replace("{" + "code" + "}", "code_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.delete_transaction_code(
                "uuid_example",
                "code_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_transaction(self, m) -> None:
        """Test case for get_transaction

        Get a transaction
        """
        path = urljoin("https://api.accounting.sh", "/transactions/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.get_transaction(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_import_transactions(self, m) -> None:
        """Test case for import_transactions

        Import transactions - INTERNAL
        """
        path = urljoin("https://api.accounting.sh", "/transactions/import")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.import_transactions(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_ledger(self, m) -> None:
        """Test case for ledger

        List company's transactions and transfers
        """
        path = urljoin("https://api.accounting.sh", "/transactions/ledger")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.ledger(
                "fields_example",
                "page_example",
                "per_page_example",
                "account_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_links(self, m) -> None:
        """Test case for list_links

        List a transaction links
        """
        path = urljoin("https://api.accounting.sh", "/transactions/{uuid}/links")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.list_links(
                "fields_example",
                "page_example",
                "per_page_example",
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_transaction_codes(self, m) -> None:
        """Test case for list_transaction_codes

        List transaction's codes
        """
        path = urljoin("https://api.accounting.sh", "/transactions/{uuid}/codes")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.list_transaction_codes(
                "uuid_example",
                "fields_example",
                "page_example",
                "per_page_example",
                "account_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_transactions(self, m) -> None:
        """Test case for list_transactions

        List company's transactions
        """
        path = urljoin("https://api.accounting.sh", "/transactions")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.list_transactions(
                "fields_example",
                "page_example",
                "per_page_example",
                "account_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_link(self, m) -> None:
        """Test case for update_link

        Update a transaction link
        """
        path = urljoin(
            "https://api.accounting.sh", "/transactions/{uuid}/links/{link_uuid}"
        )
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        path = path.replace("{" + "link_uuid" + "}", "link_uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.update_link(
                {},
                "uuid_example",
                "link_uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_transaction(self, m) -> None:
        """Test case for update_transaction

        Update a transaction
        """
        path = urljoin("https://api.accounting.sh", "/transactions/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.update_transaction(
                "uuid_example",
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_transaction_code(self, m) -> None:
        """Test case for update_transaction_code

        Update a transaction's code
        """
        path = urljoin("https://api.accounting.sh", "/transactions/{uuid}/codes")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.update_transaction_code(
                "uuid_example",
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_view_link(self, m) -> None:
        """Test case for view_link

        View a transaction link
        """
        path = urljoin(
            "https://api.accounting.sh", "/transactions/{uuid}/links/{link_uuid}"
        )
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        path = path.replace("{" + "link_uuid" + "}", "link_uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.transactions_api.view_link(
                "uuid_example",
                "link_uuid_example",
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.currency_api import CurrencyApi


class TestCurrencyApi(unittest.TestCase):
    """CurrencyApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.currency_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_get_exchange_rate(self, m) -> None:
        """Test case for get_exchange_rate

        Get the latest currency exchange rate
        """
        path = urljoin("https://api.accounting.sh", "/currency/{from}/{to}")
        path = path.replace("{" + "from" + "}", "var_from_example")
        path = path.replace("{" + "to" + "}", "to_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.currency_api.get_exchange_rate(
                "var_from_example",
                "to_example",
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.tax_api import TaxApi


class TestTaxApi(unittest.TestCase):
    """TaxApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.tax_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_get_tax_rate(self, m) -> None:
        """Test case for get_tax_rate

        Get the latest tax rate for a country
        """
        path = urljoin("https://api.accounting.sh", "/tax/{country}")
        path = path.replace("{" + "country" + "}", "country_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.tax_api.get_tax_rate(
                "country_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_verify_vat_id(self, m) -> None:
        """Test case for verify_vat_id

        Verify a VAT ID
        """
        path = urljoin("https://api.accounting.sh", "/vat/verify/{number}")
        path = path.replace("{" + "number" + "}", "number_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.tax_api.verify_vat_id(
                "number_example",
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import warnings
from datetime import date, datetime
from json import dumps
from typing import Any, Dict, List, Optional, Tuple, Union
from urllib.parse import urlencode

from typing_extensions import Annotated


class ExpenseReportsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, accounting) -> None:
        self.accounting = accounting

    def add_expense_report(
        self, add_expense_report_request: dict, **kwargs
    ) -> Any | None:
        """Add an expense report


        :param add_expense_report_request: (required)
        :type add_expense_report_request: AddExpenseReportRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/expenses/expense-reports"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if add_expense_report_request is not None:
            kwargs["json"] = add_expense_report_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)

    def delete_expense_report(self, uuid: str, **kwargs) -> Any | None:
        """Delete an expense report


        :param uuid: The expense report uuid (required)
        :type uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/expenses/expense-reports/{uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="DELETE", path=path, **kwargs)

    def expense_report_o_auth_login(self, method: str, **kwargs) -> Any | None:
        """OAuth Login


        :param method: The OAuth Provider to use (required)
        :type method: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/expenses/expense-reports/login/{method}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if method is not None:
            path = path.replace("{" + "method" + "}", method)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def get_expense_report(self, uuid: str, **kwargs) -> Any | None:
        """Get an expense report


        :param uuid: The expense report uuid (required)
        :type uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/expenses/expense-reports/{uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def get_expense_report_account(self, **kwargs) -> Any | None:
        """Get the currently connected expense report user details


        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/expenses/expense-reports/me"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def get_expense_report_user(self, uuid: str, **kwargs) -> Any | None:
        """Get an user details


        :param uuid: The expense report user uuid (required)
        :type uuid: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/expenses/expense-reports/users/{uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def list_expense_reports(
        self, fields: str = None, page: str = None, per_page: str = None, **kwargs
    ) -> Any | None:
        """List company's expense reports.

        List company's expense reports. If the token used has the `expense_report.limited_to_self` permission, this will only list the user's expense reports

        :param fields: A comma separated list of fields requested in the response
        :type fields: str
        :param page: The response page
        :type page: str
        :param per_page: The number of items per page
        :type per_page: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/expenses/expense-reports"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if fields is not None:

            query_params["fields"] = fields

        if page is not None:

            query_params["page"] = page

        if per_page is not None:

            query_params["per_page"] = per_page

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def send_expense_report_login_email(
        self, send_expense_report_login_email_request: dict, **kwargs
    ) -> Any | None:
        """Request login email


        :param send_expense_report_login_email_request: (required)
        :type send_expense_report_login_email_request: SendExpenseReportLoginEmailRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/expenses/expense-reports/login"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if send_expense_report_login_email_request is not None:
            kwargs["json"] = send_expense_report_login_email_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)

    def update_expense_report(
        self, uuid: str, add_expense_report_request: dict, **kwargs
    ) -> Any | None:
        """Update an expense report


        :param uuid: The expense report uuid (required)
        :type uuid: str
        :param add_expense_report_request: (required)
        :type add_expense_report_request: AddExpenseReportRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/expenses/expense-reports/{uuid}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if uuid is not None:
            path = path.replace("{" + "uuid" + "}", uuid)
        if add_expense_report_request is not None:
            kwargs["json"] = add_expense_report_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="PUT", path=path, **kwargs)

    def update_expense_report_account(
        self, update_expense_report_account_request: dict, **kwargs
    ) -> Any | None:
        """Update the currently connected expense report user


        :param update_expense_report_account_request: (required)
        :type update_expense_report_account_request: UpdateExpenseReportAccountRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/expenses/expense-reports/me"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if update_expense_report_account_request is not None:
            kwargs["json"] = update_expense_report_account_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="PUT", path=path, **kwargs)

    def update_expense_report_settings(
        self, update_expense_report_settings_request: dict, **kwargs
    ) -> Any | None:
        """Retrieve company settings for expense reports

        At least an url or a company must be provided

        :param update_expense_report_settings_request: (required)
        :type update_expense_report_settings_request: UpdateExpenseReportSettingsRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/expenses/expense-reports/settings"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if update_expense_report_settings_request is not None:
            kwargs["json"] = update_expense_report_settings_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)

    def verify_expense_report_settings(
        self, verify_expense_report_settings_request: dict, **kwargs
    ) -> Any | None:
        """Verify expense reports settings


        :param verify_expense_report_settings_request: (required)
        :type verify_expense_report_settings_request: VerifyExpenseReportSettingsRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/expenses/expense-reports/verify"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if verify_expense_report_settings_request is not None:
            kwargs["json"] = verify_expense_report_settings_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import datetime
import uuid
from typing import Any
from urllib.parse import urljoin

import requests

from accounting_sh.api.account_connections_api import AccountConnectionsApi
from accounting_sh.api.accounting_codes_api import AccountingCodesApi
from accounting_sh.api.accounts_api import AccountsApi
from accounting_sh.api.attachments_api import AttachmentsApi
from accounting_sh.api.auth_api import AuthApi
from accounting_sh.api.bills_api import BillsApi
from accounting_sh.api.categories_api import CategoriesApi
from accounting_sh.api.companies_api import CompaniesApi
from accounting_sh.api.contacts_api import ContactsApi
from accounting_sh.api.countries_api import CountriesApi
from accounting_sh.api.credentials_api import CredentialsApi
from accounting_sh.api.currency_api import CurrencyApi
from accounting_sh.api.documents_api import DocumentsApi
from accounting_sh.api.expense_reports_api import ExpenseReportsApi
from accounting_sh.api.export_api import ExportApi
from accounting_sh.api.invoices_api import InvoicesApi
from accounting_sh.api.logs_api import LogsApi
from accounting_sh.api.notification_api import NotificationApi
from accounting_sh.api.notification_types_api import NotificationTypesApi
from accounting_sh.api.o_auth_config_api import OAuthConfigApi
from accounting_sh.api.payments_api import PaymentsApi
from accounting_sh.api.quotes_api import QuotesApi
from accounting_sh.api.receipts_api import ReceiptsApi
from accounting_sh.api.revenues_api import RevenuesApi
from accounting_sh.api.rossum_api import RossumApi
from accounting_sh.api.search_api import SearchApi
from accounting_sh.api.settings_api import SettingsApi
from accounting_sh.api.statistics_api import StatisticsApi
from accounting_sh.api.tags_api import TagsApi
from accounting_sh.api.tax_api import TaxApi
from accounting_sh.api.transactions_api import TransactionsApi
from accounting_sh.api.transfers_api import TransfersApi
from accounting_sh.api.users_api import UsersApi
from accounting_sh.api.vatid_api import VATIDApi
from accounting_sh.api.webhooks_api import WebhooksApi
from accounting_sh.exceptions import ApiException


class Accounting:
    def __init__(
        self,
        token: str,
        url: str = "https://api.accounting.sh",
        throw_errors: bool = True,
    ):
        self.token = token
        self.url = url
        self.throw_errors = throw_errors

    @property
    def account_connections_api(self) -> AccountConnectionsApi:
        """
        :return: AccountConnectionsApi instance
        """
        return AccountConnectionsApi(self)

    @property
    def accounting_codes_api(self) -> AccountingCodesApi:
        """
        :return: AccountingCodesApi instance
        """
        return AccountingCodesApi(self)

    @property
    def accounts_api(self) -> AccountsApi:
        """
        :return: AccountsApi instance
        """
        return AccountsApi(self)

    @property
    def attachments_api(self) -> AttachmentsApi:
        """
        :return: AttachmentsApi instance
        """
        return AttachmentsApi(self)

    @property
    def auth_api(self) -> AuthApi:
        """
        :return: AuthApi instance
        """
        return AuthApi(self)

    @property
    def bills_api(self) -> BillsApi:
        """
        :return: BillsApi instance
        """
        return BillsApi(self)

    @property
    def categories_api(self) -> CategoriesApi:
        """
        :return: CategoriesApi instance
        """
        return CategoriesApi(self)

    @property
    def companies_api(self) -> CompaniesApi:
        """
        :return: CompaniesApi instance
        """
        return CompaniesApi(self)

    @property
    def contacts_api(self) -> ContactsApi:
        """
        :return: ContactsApi instance
        """
        return ContactsApi(self)

    @property
    def countries_api(self) -> CountriesApi:
        """
        :return: CountriesApi instance
        """
        return CountriesApi(self)

    @property
    def credentials_api(self) -> CredentialsApi:
        """
        :return: CredentialsApi instance
        """
        return CredentialsApi(self)

    @property
    def currency_api(self) -> CurrencyApi:
        """
        :return: CurrencyApi instance
        """
        return CurrencyApi(self)

    @property
    def documents_api(self) -> DocumentsApi:
        """
        :return: DocumentsApi instance
        """
        return DocumentsApi(self)

    @property
    def expense_reports_api(self) -> ExpenseReportsApi:
        """
        :return: ExpenseReportsApi instance
        """
        return ExpenseReportsApi(self)

    @property
    def export_api(self) -> ExportApi:
        """
        :return: ExportApi instance
        """
        return ExportApi(self)

    @property
    def invoices_api(self) -> InvoicesApi:
        """
        :return: InvoicesApi instance
        """
        return InvoicesApi(self)

    @property
    def logs_api(self) -> LogsApi:
        """
        :return: LogsApi instance
        """
        return LogsApi(self)

    @property
    def notification_api(self) -> NotificationApi:
        """
        :return: NotificationApi instance
        """
        return NotificationApi(self)

    @property
    def notification_types_api(self) -> NotificationTypesApi:
        """
        :return: NotificationTypesApi instance
        """
        return NotificationTypesApi(self)

    @property
    def o_auth_config_api(self) -> OAuthConfigApi:
        """
        :return: OAuthConfigApi instance
        """
        return OAuthConfigApi(self)

    @property
    def payments_api(self) -> PaymentsApi:
        """
        :return: PaymentsApi instance
        """
        return PaymentsApi(self)

    @property
    def quotes_api(self) -> QuotesApi:
        """
        :return: QuotesApi instance
        """
        return QuotesApi(self)

    @property
    def receipts_api(self) -> ReceiptsApi:
        """
        :return: ReceiptsApi instance
        """
        return ReceiptsApi(self)

    @property
    def revenues_api(self) -> RevenuesApi:
        """
        :return: RevenuesApi instance
        """
        return RevenuesApi(self)

    @property
    def rossum_api(self) -> RossumApi:
        """
        :return: RossumApi instance
        """
        return RossumApi(self)

    @property
    def search_api(self) -> SearchApi:
        """
        :return: SearchApi instance
        """
        return SearchApi(self)

    @property
    def settings_api(self) -> SettingsApi:
        """
        :return: SettingsApi instance
        """
        return SettingsApi(self)

    @property
    def statistics_api(self) -> StatisticsApi:
        """
        :return: StatisticsApi instance
        """
        return StatisticsApi(self)

    @property
    def tags_api(self) -> TagsApi:
        """
        :return: TagsApi instance
        """
        return TagsApi(self)

    @property
    def tax_api(self) -> TaxApi:
        """
        :return: TaxApi instance
        """
        return TaxApi(self)

    @property
    def transactions_api(self) -> TransactionsApi:
        """
        :return: TransactionsApi instance
        """
        return TransactionsApi(self)

    @property
    def transfers_api(self) -> TransfersApi:
        """
        :return: TransfersApi instance
        """
        return TransfersApi(self)

    @property
    def users_api(self) -> UsersApi:
        """
        :return: UsersApi instance
        """
        return UsersApi(self)

    @property
    def vatid_api(self) -> VATIDApi:
        """
        :return: VATIDApi instance
        """
        return VATIDApi(self)

    @property
    def webhooks_api(self) -> WebhooksApi:
        """
        :return: WebhooksApi instance
        """
        return WebhooksApi(self)

    def _serialize(self, data):
        if isinstance(data, list):
            for i in range(len(data)):
                data[i] = self._serialize(data[i])
        elif isinstance(data, dict):
            for key, value in data.items():
                data[key] = self._serialize(value)
        elif isinstance(data, datetime.datetime):
            return data.isoformat()
        elif isinstance(data, datetime.date):
            return data.strftime("%Y-%m-%d")
        elif isinstance(data, uuid.UUID):
            return str(data)

        return data

    def request(
        self, method: str, path: str, comment: str = None, **kwargs
    ) -> Any | None:
        """
        :param method:
        :param path:
        :param comment:
        :param kwargs:
        :return:
        """
        kwargs.setdefault("headers", {})
        kwargs["headers"]["Authorization"] = f"Bearer {self.token}"
        kwargs["headers"]["User-Agent"] = "AccountingSh/1.3.3/python"

        if comment is not None:
            kwargs["headers"]["X-Audit-Comment"] = comment

        if "json" in kwargs:
            kwargs["json"] = self._serialize(kwargs["json"])

        resp = requests.request(method, urljoin(self.url, path), **kwargs)

        if 200 <= resp.status_code <= 300:
            if resp.headers.get("Content-Type") == "application/json":
                return resp.json()
            else:
                return resp.text

        if self.throw_errors:
            raise ApiException(resp.status_code, resp.text, resp.headers)

        return None



# coding: utf-8

"""
Accounting API


The version of the OpenAPI document: 8.3.9
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.settings_api import SettingsApi


class TestSettingsApi(unittest.TestCase):
    """SettingsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.settings_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_get_settings(self, m) -> None:
        """Test case for get_settings

        Get a company's settings
        """
        path = urljoin("https://api.accounting.sh", "/companies/{uuid}/settings/{key}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        path = path.replace("{" + "key" + "}", "key_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.settings_api.get_settings(
                "uuid_example",
                "key_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_settings(self, m) -> None:
        """Test case for list_settings

        List company's settings
        """
        path = urljoin("https://api.accounting.sh", "/companies/{uuid}/settings")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.settings_api.list_settings(
                "fields_example",
                "page_example",
                "per_page_example",
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_settings(self, m) -> None:
        """Test case for update_settings

        Update a company's settings
        """
        path = urljoin("https://api.accounting.sh", "/companies/{uuid}/settings/{key}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        path = path.replace("{" + "key" + "}", "key_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.settings_api.update_settings(
                "uuid_example",
                "key_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()
